#
# spec file for package apache2-mod_authnz_external
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define mod_name mod_authnz_external
#
Name:           apache2-mod_authnz_external
Version:        3.3.2
Release:        5.7
#
Summary:        Apache External Authentication Modules
License:        Apache-2.0
#
Group:          Productivity/Networking/Web/Servers
#
Url:            http://code.google.com/p/mod-auth-external/
Source:         http://mod-auth-external.googlecode.com/files/%{mod_name}-%{version}.tar.gz
BuildRequires:  apache2-devel
BuildRequires:  apache-rpm-macros
BuildRequires:  curl
Requires:       %{apache_mmn}
Requires:       %{apache_suse_maintenance_mmn}
Requires:       apache2 >= 2.3
# imho pwauth is not strictly needed?
#Requires:       pwauth
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The Apache HTTP Daemon can be configured to require users to supply logins and
passwords before accessing pages in some directories. Authentication is the
process of checking if the password given is correct for a user. Apache has
standard modules for authenticating out of several different kinds of
databases. These external authentication modules provide a flexible tool for
creating authentication systems based on other databases.

%prep
%setup -q -n %{mod_name}-%{version}
# it would introduce dependency on /usr/bin/php :-/
chmod -x test/test.pipe.php
rm -rf .libs/ .*.swp

%build
%{apache_apxs} -c %{mod_name}.c

%install
install -Dd -m 0755 %{buildroot}%{apache_libexecdir}
%{apache_apxs} -S LIBEXECDIR="%{buildroot}%{apache_libexecdir}" -i -n %{mod_name} %{mod_name}.la

%check
set +x
mkdir -p %{apache_test_module_dir}/htdocs/protected
# create test document
cat << EOF >  %{apache_test_module_dir}/htdocs/protected/index.html
RESTRICTED AREA
EOF
# create external authenticifation provider
cat << EOF > %{apache_test_module_dir}/dummy-auth
#!/bin/bash
read user
read passwd
if [ "\$user" == "\$passwd" ]; then
  exit 0
else
  exit 1
fi
EOF
chmod +x %{apache_test_module_dir}/dummy-auth
# create module conf
cat << EOF > %{apache_test_module_dir}/%{mod_name}-test.conf
DefineExternalAuth dummy_auth pipe %{apache_test_module_dir}/dummy-auth
<Directory %{apache_test_module_dir}/htdocs/protected>
  AuthType Basic
  AuthName "Restricted Area"
  AuthBasicProvider external
  AuthExternal dummy_auth
  Require valid-user
</Directory>
EOF
# run test apache instance
exit_code=0
%apache_test_module_start_apache -m authn_core:authz_user:authnz_external -i %{mod_name}-test.conf
echo
echo 'Test /protected/ output'
# this must to be authenticated
%apache_test_module_curl -u wilma:wilma -d /protected/ -o output.txt
grep 'RESTRICTED AREA' output.txt || exit_code=1
# this must not to be authenticated
%apache_test_module_curl -u wilma:betty -d /protected/ -o output.txt
grep '<title>.*401.*</title>' output.txt || exit_code=1
echo -n 'Result: '
if [ $exit_code -eq 0 ]; then
  echo 'SUCCESS'
else
  echo "FAILED, error_log:"
  cat %{apache_test_module_dir}/error_log
fi
echo
# stop test apache instance
%apache_test_module_stop_apache
set -x
exit $exit_code

%files
%defattr(-,root,root,-)
%{apache_libexecdir}/%{mod_name}.so
%doc test/
%doc AUTHENTICATORS CHANGES INSTALL* README TODO UPGRADE

%changelog
* Sun Oct  4 2015 pgajdos@suse.com
- module is not compatible with Apache 2.2
* Fri Sep 25 2015 pgajdos@suse.com
- test module with %%apache_test_module_curl
* Thu Jul 16 2015 pgajdos@suse.com
- Requries: %%{apache_suse_maintenance_mmn}
  This will pull this module to the update (in released distribution)
  when apache maintainer thinks it is good (due api/abi changes).
* Fri Oct 31 2014 pgajdos@suse.com
- call spec-cleaner
- use apache rpm macros
* Wed Mar 19 2014 asvetter@cip.physik.uni-wuerzburg.de
- changed source from _service to a real file
* Tue Feb  4 2014 asvetter@cip.physik.uni-wuerzburg.de
- added Requires: apache2 > 2.3
* Mon Feb  3 2014 asvetter@cip.physik.uni-wuerzburg.de
- update to v3.3.2 (latest version for Apache 2.4)
  - Replaced reference to remote_ip field of the connection record with
  useragent_ip, due to the elimination of remote_ip in Apache 2.4.1. Thanks
  to davidsansome and cjwatson for pointing out the need for this.
  - Fixed a bug with setting of GROUP environment variable. Thanks to
  ddarbyson for reporting this, and Guoan Hu for posting the fix.
  - Added test/test.pipe.php, a PHP version of test/test.pipe contributed
* Sun Feb 17 2013 pieter@hollants.com
- update to version 3.2.6 (latest version for Apache 2.2):
  - Rewrite of external authenticator launching code to use Apache's
    cross-OS process/thread library
  - Support for AuthExternalContext and GroupExternalError directives
  - Dropped RADIUS code due to licensing issues
  - AuthExternal now supports calling multiple authenticators
  - Correct SQL injection flaw in sample MySQL authenticator
  - Improved documentation and cleanups
* Tue Jun 10 2008 poeml@suse.de
- build service supports the debuginfo flag in metadata now; remove
  debug_package macro from the specfile therefore.
* Fri Apr 28 2006 mrueckert@suse.de
- Initial package of version 3.1.0
